==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
var YesterdayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(YesterdayExpressionDescriptionMetadata, _super);
    function YesterdayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YesterdayExpressionDescriptionMetadata.b = function (a) {
        if (YesterdayExpressionDescriptionMetadata.a == null) {
            YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
        }
        if (a.j(YesterdayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    YesterdayExpressionDescriptionMetadata.d = function (a) {
        YesterdayExpressionDescriptionMetadata.b(a);
        a.aa("YesterdayExpression", function () { return new YesterdayExpressionDescription(); });
        a.z("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.$t = markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
}(Base));
export { YesterdayExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
var YesterdayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(YesterdayExpressionDescriptionMetadata, _super);
    function YesterdayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YesterdayExpressionDescriptionMetadata.b = function (a) {
        if (YesterdayExpressionDescriptionMetadata.a == null) {
            YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
        }
        if (a.k(YesterdayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    YesterdayExpressionDescriptionMetadata.d = function (a) {
        YesterdayExpressionDescriptionMetadata.b(a);
        a.ac("YesterdayExpression", function () { return new YesterdayExpressionDescription(); });
        a.ab("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.$t = markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
}(Base));
export { YesterdayExpressionDescriptionMetadata };
